@@ -244,7 +244,7 @@ PlayPauseAction::engineStateChanged( Engine::State state,  Engine::State /*oldSt
     //update menu texts for this special action
     for( int x = 0; x < containerCount(); ++x ) {
         TQWidget *w = container( x );
-        if( w->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ) )
+        if( w->inherits( "TQPopupMenu" ) )
             static_cast<TQPopupMenu*>(w)->changeItem( itemId( x ), text );
         //TODO TDEToolBar sucks so much
 //         else if( w->inherits( "TDEToolBar" ) )
