@@ -78,6 +78,8 @@ email                : markey@web.de
 #include <tqtimer.h>              //showHyperThreadingWarning()
 #include <tqtooltip.h>            //default tooltip for trayicon
 
+#define TStringToTQString(s) TQString::fromUtf8((s).toCString(true))
+
 // For the HyperThreading fix
 #ifdef __linux__
     #ifdef SCHEDAFFINITY_SUPPORT
@@ -589,7 +591,7 @@ class ID3v1StringHandler : public TagLib::ID3v1::StringHandler
 
     virtual TagLib::ByteVector render( const TagLib::String &ts ) const
     {
-        const TQCString qcs = m_codec->fromUnicode( TStringToQString(ts) );
+        const TQCString qcs = m_codec->fromUnicode( TStringToTQString(ts) );
         return TagLib::ByteVector( qcs, qcs.length() );
     }
 
