@@ -32,7 +32,7 @@
 */
 class ClickLineEdit : public KLineEdit
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     TQ_PROPERTY( TQString clickMessage READ clickMessage WRITE setClickMessage )
     public:
