@@ -34,36 +34,36 @@
 #include <tqtooltip.h>
 #include <tqvbox.h>
 
-#include <kapplication.h>
-#include <kconfig.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
 #include <kcursor.h>
-#include <kfiledialog.h>
+#include <tdefiledialog.h>
 #include <kiconloader.h>
-#include <klistview.h>
-#include <klocale.h>
-#include <kmessagebox.h>    //showCoverMenu()
-#include <kmultipledrag.h>
-#include <kio/netaccess.h>
-#include <kpopupmenu.h>    //showCoverMenu()
+#include <tdelistview.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>    //showCoverMenu()
+#include <tdemultipledrag.h>
+#include <tdeio/netaccess.h>
+#include <tdepopupmenu.h>    //showCoverMenu()
 #include <kprogress.h>
 #include <kpushbutton.h>
 #include <ksqueezedtextlabel.h> //status label
 #include <kstatusbar.h>
 #include <kstringhandler.h>    //paintItem
-#include <ktoolbar.h>
-#include <ktoolbarbutton.h>    //clear filter button
+#include <tdetoolbar.h>
+#include <tdetoolbarbutton.h>    //clear filter button
 #include <kurl.h>
 #include <kurldrag.h>
-#include <kwin.h>
+#include <twin.h>
 
 static TQString artistToSelectInInitFunction;
 CoverManager *CoverManager::s_instance = 0;
 
-class ArtistItem : public KListViewItem
+class ArtistItem : public TDEListViewItem
 {
     public:
     ArtistItem(TQListView *view, TQListViewItem *item, const TQString &text)
-        : KListViewItem(view, item, text) {}
+        : TDEListViewItem(view, item, text) {}
     protected:
     int compare( TQListViewItem* i, int col, bool ascending ) const
     {
@@ -101,7 +101,7 @@ CoverManager::CoverManager()
     setMargin( 4 );
 
     //artist listview
-    m_artistView = new KListView( this );
+    m_artistView = new TDEListView( this );
     m_artistView->addColumn(i18n( "Albums By" ));
     m_artistView->setFullWidth( true );
     m_artistView->setSorting( 0 );
@@ -130,7 +130,7 @@ CoverManager::CoverManager()
     qb.setLimit( 0, 1 );
     if ( qb.run().count() ) {
         item = new ArtistItem( m_artistView, last, i18n( "Various Artists" ) );
-        item->setPixmap( 0, SmallIcon("personal") );
+        item->setPixmap( 0, SmallIcon("preferences-desktop-personal") );
     }
 
     TQVBox *vbox = new TQVBox( this );
@@ -141,8 +141,8 @@ CoverManager::CoverManager()
 
     { //<Search LineEdit>
         TQHBox *searchBox = new TQHBox( hbox );
-        KToolBar* searchToolBar = new Browser::ToolBar( searchBox );
-        KToolBarButton *button = new KToolBarButton( "locationbar_erase", 0, searchToolBar );
+        TDEToolBar* searchToolBar = new Browser::ToolBar( searchBox );
+        TDEToolBarButton *button = new TDEToolBarButton( "locationbar_erase", 0, searchToolBar );
         m_searchEdit = new ClickLineEdit( i18n( "Enter search terms here" ), searchToolBar );
         m_searchEdit->setFrame( TQFrame::Sunken );
 
@@ -156,7 +156,7 @@ CoverManager::CoverManager()
     } //</Search LineEdit>
 
     // view menu
-    m_viewMenu = new KPopupMenu( this );
+    m_viewMenu = new TDEPopupMenu( this );
     m_viewMenu->insertItem( i18n("All Albums"), AllAlbums );
     m_viewMenu->insertItem( i18n("Albums With Cover"), AlbumsWithCover );
     m_viewMenu->insertItem( i18n("Albums Without Cover"), AlbumsWithoutCover );
@@ -165,7 +165,7 @@ CoverManager::CoverManager()
 
     #ifdef AMAZON_SUPPORT
     // amazon locale menu
-    m_amazonLocaleMenu = new KPopupMenu( this );
+    m_amazonLocaleMenu = new TDEPopupMenu( this );
     m_amazonLocaleMenu->insertItem( i18n("International"), CoverFetcher::International );
     m_amazonLocaleMenu->insertItem( i18n("Canada"), CoverFetcher::Canada );
     m_amazonLocaleMenu->insertItem( i18n("France"), CoverFetcher::France );
@@ -175,12 +175,12 @@ CoverManager::CoverManager()
     connect( m_amazonLocaleMenu, TQT_SIGNAL( activated(int) ), TQT_SLOT( changeLocale(int) ) );
     #endif
 
-    KToolBar* toolBar = new KToolBar( hbox );
-    toolBar->setIconText( KToolBar::IconTextRight );
+    TDEToolBar* toolBar = new TDEToolBar( hbox );
+    toolBar->setIconText( TDEToolBar::IconTextRight );
     toolBar->setFrameShape( TQFrame::NoFrame );
     toolBar->insertButton( "view_choose", 1, m_viewMenu, true, i18n( "View" ) );
     #ifdef AMAZON_SUPPORT
-    toolBar->insertButton( "babelfish", 2, m_amazonLocaleMenu, true, i18n( "Amazon Locale" ) );
+    toolBar->insertButton( "amazon_locale", 2, m_amazonLocaleMenu, true, i18n( "Amazon Locale" ) );
 
     TQString locale = AmarokConfig::amazonLocale();
     m_currentLocale = CoverFetcher::localeStringToID( locale );
@@ -199,7 +199,7 @@ CoverManager::CoverManager()
     m_statusBar->addWidget( m_statusLabel = new KSqueezedTextLabel( m_statusBar ), 4 );
     m_statusLabel->setIndent( 3 );
     m_statusBar->addWidget( m_progressBox = new TQHBox( m_statusBar ), 1, true );
-    KPushButton *stopButton = new KPushButton( KGuiItem(i18n("Abort"), "stop"), m_progressBox );
+    KPushButton *stopButton = new KPushButton( KGuiItem(i18n("Abort"), "process-stop"), m_progressBox );
     connect( stopButton, TQT_SIGNAL(clicked()), TQT_SLOT(stopFetching()) );
     m_progress = new KProgress( m_progressBox );
     m_progress->setCenterIndicator( true );
@@ -486,7 +486,7 @@ void CoverManager::showCoverMenu( TQIconViewItem *item, const TQPoint &p ) //SLO
 
     enum { SHOW, FETCH, CUSTOM, DELETE, APPEND };
 
-    KPopupMenu menu;
+    TDEPopupMenu menu;
 
     menu.insertTitle( i18n( "Cover Image" ) );
 
@@ -736,7 +736,7 @@ void CoverManager::setCustomSelectedCovers()
             CollectionDB::instance()->setAlbumImage( item->artist(), item->album(), image );
             item->loadCover();
         }
-        KIO::NetAccess::removeTempFile( tmpFile );
+        TDEIO::NetAccess::removeTempFile( tmpFile );
     }
 }
 
@@ -885,7 +885,7 @@ void CoverManager::setStatusText( TQString text )
 /////////////////////////////////////////////////////////////////////
 
 CoverView::CoverView( TQWidget *parent, const char *name, WFlags f )
-    : KIconView( parent, name, f )
+    : TDEIconView( parent, name, f )
 {
     Debug::Block block( __PRETTY_FUNCTION__ );
 
@@ -952,7 +952,7 @@ void CoverView::setStatusText( TQIconViewItem *item )
 /////////////////////////////////////////////////////////////////////
 
 CoverViewItem::CoverViewItem( TQIconView *parent, TQIconViewItem *after, const TQString &artist, const TQString &album )
-    : KIconViewItem( parent, after, album )
+    : TDEIconViewItem( parent, after, album )
     , m_artist( artist )
     , m_album( album )
     , m_coverImagePath( CollectionDB::instance()->albumImage( m_artist, m_album, false, 0, &m_embedded ) )
