@@ -28,17 +28,17 @@
 #include <tqimage.h>
 #include <tqtimer.h>
 
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
 #include <kinputdialog.h>         //setupCoverFetcher()
-#include <kio/job.h>
+#include <tdeio/job.h>
 #include <klineedit.h>            //setupCoverFetcher()
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kmdcodec.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
-#include <kio/netaccess.h>
+#include <tdeio/netaccess.h>
 
 #include <cmath>                 //DbConnection::sqlite_power()
 #include <ctime>                 //query()
@@ -80,8 +80,8 @@ CollectionDB::CollectionDB()
     m_cacheDir.cd( "albumcovers/cache" );
 
     // Load DBEngine plugin
-    TQString query = "[X-KDE-Amarok-plugintype] == 'dbengine' and [X-KDE-Amarok-name] != '%1'";
-    KTrader::OfferList offers = PluginManager::query( query.arg( "sqlite-dbengine" ) );
+    TQString query = "[X-TDE-Amarok-plugintype] == 'dbengine' and [X-TDE-Amarok-name] != '%1'";
+    TDETrader::OfferList offers = PluginManager::query( query.arg( "sqlite-dbengine" ) );
     m_dbEngine = (DBEngine*) PluginManager::createFromService( offers.first() );
 
     //<OPEN DATABASE>
@@ -89,7 +89,7 @@ CollectionDB::CollectionDB()
     //</OPEN DATABASE>
 
     // TODO: Should write to config in dtor, but it crashes...
-    KConfig* config = amaroK::config( "Collection Browser" );
+    TDEConfig* config = amaroK::config( "Collection Browser" );
     config->writeEntry( "Database Version", DATABASE_VERSION );
     config->writeEntry( "Database Stats Version", DATABASE_STATS_VERSION );
 
@@ -107,7 +107,7 @@ CollectionDB::~CollectionDB()
     destroy();
 
 //     This crashes so it's done at the end of ctor.
-//     KConfig* const config = amaroK::config( "Collection Browser" );
+//     TDEConfig* const config = amaroK::config( "Collection Browser" );
 //     config->writeEntry( "Database Version", DATABASE_VERSION );
 //     config->writeEntry( "Database Stats Version", DATABASE_STATS_VERSION );
 }
@@ -693,7 +693,7 @@ CollectionDB::fetchImage(const KURL& url, TQString &/*tmpFile*/)
     if(url.protocol() != "file")
     {
         TQString tmpFile;
-        KIO::NetAccess::download( url, tmpFile, 0); //TODO set 0 to the window, though it probably doesn't really matter
+        TDEIO::NetAccess::download( url, tmpFile, 0); //TODO set 0 to the window, though it probably doesn't really matter
         return TQImage(tmpFile);
     }
     else
@@ -707,7 +707,7 @@ CollectionDB::setAlbumImage( const TQString& artist, const TQString& album, cons
 {
     TQString tmpFile;
     bool success = setAlbumImage( artist, album, fetchImage(url, tmpFile) );
-    KIO::NetAccess::removeTempFile( tmpFile ); //only removes file if it was created with NetAccess
+    TDEIO::NetAccess::removeTempFile( tmpFile ); //only removes file if it was created with NetAccess
     return success;
 }
 
@@ -1802,7 +1802,7 @@ CollectionDB::initialize()
     DbConnection *dbConn = m_dbConnPool->getDbConnection();
     m_dbConnPool->putDbConnection( dbConn );
 
-    KConfig* config = amaroK::config( "Collection Browser" );
+    TDEConfig* config = amaroK::config( "Collection Browser" );
     if(!dbConn->isConnected())
         amaroK::MessageQueue::instance()->addMessage(dbConn->lastError());
     if ( !dbConn->isInitialized() || !isValid() )
