@@ -25,10 +25,10 @@
 
 #include "ktrm.h"
 
-#include <kapplication.h>
-#include <kio/job.h>
-#include <kio/jobclasses.h>
-#include <kprotocolmanager.h>
+#include <tdeapplication.h>
+#include <tdeio/job.h>
+#include <tdeio/jobclasses.h>
+#include <tdeprotocolmanager.h>
 #include <kurl.h>
 #include <kresolver.h>
 
@@ -252,7 +252,7 @@ class KTRMEventHandler : public TQObject
 public:
     static void send(int fileId, KTRMEvent::Status status)
     {
-        KApplication::postEvent(instance(), new KTRMEvent(fileId, status));
+        TDEApplication::postEvent(instance(), new KTRMEvent(fileId, status));
     }
 
 protected:
@@ -731,26 +731,26 @@ void KTRMLookup::puidGenerated()
     tp_ReleaseTrack(KTRMRequestHandler::instance()->tunePimp(), track);
     d->results.clear();
 
-    KIO::Job *job = KIO::storedGet( TQString( "http://musicbrainz.org/ws/1/track/?type=xml&puid=%1" ).arg( puid ) , false, false );
+    TDEIO::Job *job = TDEIO::storedGet( TQString( "http://musicbrainz.org/ws/1/track/?type=xml&puid=%1" ).arg( puid ) , false, false );
 
     Amarok::StatusBar::instance()->newProgressOperation( job )
             .setDescription( i18n( "MusicBrainz Lookup" ) );
 
-    connect( job, TQT_SIGNAL( result( KIO::Job* ) ), TQT_SLOT( lookupResult( KIO::Job* ) ) );
+    connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), TQT_SLOT( lookupResult( TDEIO::Job* ) ) );
 #endif
 }
 
-void KTRMLookup::lookupResult( KIO::Job* job )
+void KTRMLookup::lookupResult( TDEIO::Job* job )
 {
 #if HAVE_TUNEPIMP >= 5
     DEBUG_BLOCK
     if ( !job->error() == 0 ) {
-        warning() << "[MusicBrainzLookup] KIO error! errno: " << job->error() << endl;
+        warning() << "[MusicBrainzLookup] TDEIO error! errno: " << job->error() << endl;
         Amarok::StatusBar::instance()->longMessage( "Couldn't connect to MusicBrainz server." );
         finished();
         return;
     }
-    KIO::StoredTransferJob* const storedJob = static_cast<KIO::StoredTransferJob*>( job );
+    TDEIO::StoredTransferJob* const storedJob = static_cast<TDEIO::StoredTransferJob*>( job );
     TQString xml = TQString::fromUtf8( storedJob->data().data(), storedJob->data().size() );
 
     TQDomDocument doc;
