@@ -21,7 +21,7 @@ namespace Daap {
 
     class Proxy : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
   
 
         public:
