@@ -63,6 +63,7 @@
 #include "metabundle.h"
 #include "podcastbundle.h"
 
+#define TStringToTQString(s) TQString::fromUtf8((s).toCString(true))
 
 namespace Amarok {
     KURL detachedKURL( const KURL &url ) {
@@ -75,7 +76,7 @@ namespace Amarok {
 
 
 MetaBundle::EmbeddedImage::EmbeddedImage( const TagLib::ByteVector& data, const TagLib::String& description )
-    : m_description( TStringToQString( description ) )
+    : m_description( TStringToTQString( description ) )
 {
     m_data.duplicate( data.data(), data.size() );
 }
@@ -511,7 +512,7 @@ MetaBundle::readTags( TagLib::AudioProperties::ReadStyle readStyle, EmbeddedImag
         tag = fileref.tag();
         if ( tag )
         {
-            #define strip( x ) TQString(TStringToQString( x )).stripWhiteSpace()
+            #define strip( x ) TStringToTQString( x ).stripWhiteSpace()
             setTitle( strip( tag->title() ) );
             setArtist( strip( tag->artist() ) );
             setAlbum( strip( tag->album() ) );
@@ -536,19 +537,19 @@ MetaBundle::readTags( TagLib::AudioProperties::ReadStyle readStyle, EmbeddedImag
             if ( file->ID3v2Tag() )
             {
                 if ( !file->ID3v2Tag()->frameListMap()["TPOS"].isEmpty() )
-                    disc = TQString(TStringToQString( file->ID3v2Tag()->frameListMap()["TPOS"].front()->toString() )).stripWhiteSpace();
+                    disc = TStringToTQString( file->ID3v2Tag()->frameListMap()["TPOS"].front()->toString() ).stripWhiteSpace();
 
                 if ( !file->ID3v2Tag()->frameListMap()["TBPM"].isEmpty() )
-                    setBpm( TQString(TStringToQString( file->ID3v2Tag()->frameListMap()["TBPM"].front()->toString() )).stripWhiteSpace().toFloat() );
+                    setBpm( TStringToTQString( file->ID3v2Tag()->frameListMap()["TBPM"].front()->toString() ).stripWhiteSpace().toFloat() );
 
                 if ( !file->ID3v2Tag()->frameListMap()["TCOM"].isEmpty() )
-                    setComposer( TQString(TStringToQString( file->ID3v2Tag()->frameListMap()["TCOM"].front()->toString() )).stripWhiteSpace() );
+                    setComposer( TStringToTQString( file->ID3v2Tag()->frameListMap()["TCOM"].front()->toString() ).stripWhiteSpace() );
 
                 if ( !file->ID3v2Tag()->frameListMap()["TPE2"].isEmpty() ) // non-standard: Apple, Microsoft
-                    setAlbumArtist( TQString(TStringToQString( file->ID3v2Tag()->frameListMap()["TPE2"].front()->toString() )).stripWhiteSpace() );
+                    setAlbumArtist( TStringToTQString( file->ID3v2Tag()->frameListMap()["TPE2"].front()->toString() ).stripWhiteSpace() );
 
                 if ( !file->ID3v2Tag()->frameListMap()["TCMP"].isEmpty() )
-                    compilation = TQString(TStringToQString( file->ID3v2Tag()->frameListMap()["TCMP"].front()->toString() )).stripWhiteSpace();
+                    compilation = TStringToTQString( file->ID3v2Tag()->frameListMap()["TCMP"].front()->toString() ).stripWhiteSpace();
 
                 if(images) {
                     loadImagesFromTag( *file->ID3v2Tag(), *images );
@@ -561,16 +562,16 @@ MetaBundle::readTags( TagLib::AudioProperties::ReadStyle readStyle, EmbeddedImag
             if ( file->tag() )
             {
                 if ( !file->tag()->fieldListMap()[ "COMPOSER" ].isEmpty() )
-                    setComposer( TQString(TStringToQString( file->tag()->fieldListMap()["COMPOSER"].front() )).stripWhiteSpace() );
+                    setComposer( TStringToTQString( file->tag()->fieldListMap()["COMPOSER"].front() ).stripWhiteSpace() );
 
                 if ( !file->tag()->fieldListMap()[ "BPM" ].isEmpty() )
-                    setBpm( TQString(TStringToQString( file->tag()->fieldListMap()["BPM"].front() )).stripWhiteSpace().toFloat() );
+                    setBpm( TStringToTQString( file->tag()->fieldListMap()["BPM"].front() ).stripWhiteSpace().toFloat() );
 
                 if ( !file->tag()->fieldListMap()[ "DISCNUMBER" ].isEmpty() )
-                    disc = TQString(TStringToQString( file->tag()->fieldListMap()["DISCNUMBER"].front() )).stripWhiteSpace();
+                    disc = TStringToTQString( file->tag()->fieldListMap()["DISCNUMBER"].front() ).stripWhiteSpace();
 
                 if ( !file->tag()->fieldListMap()[ "COMPILATION" ].isEmpty() )
-                    compilation = TQString(TStringToQString( file->tag()->fieldListMap()["COMPILATION"].front() )).stripWhiteSpace();
+                    compilation = TStringToTQString( file->tag()->fieldListMap()["COMPILATION"].front() ).stripWhiteSpace();
             }
         }
         else if ( TagLib::FLAC::File *file = dynamic_cast<TagLib::FLAC::File *>( fileref.file() ) )
@@ -579,16 +580,16 @@ MetaBundle::readTags( TagLib::AudioProperties::ReadStyle readStyle, EmbeddedImag
             if ( file->xiphComment() )
             {
                 if ( !file->xiphComment()->fieldListMap()[ "COMPOSER" ].isEmpty() )
-                    setComposer( TQString(TStringToQString( file->xiphComment()->fieldListMap()["COMPOSER"].front() )).stripWhiteSpace() );
+                    setComposer( TStringToTQString( file->xiphComment()->fieldListMap()["COMPOSER"].front() ).stripWhiteSpace() );
 
                 if ( !file->xiphComment()->fieldListMap()[ "BPM" ].isEmpty() )
-                    setBpm( TQString(TStringToQString( file->xiphComment()->fieldListMap()["BPM"].front() )).stripWhiteSpace().toFloat() );
+                    setBpm( TStringToTQString( file->xiphComment()->fieldListMap()["BPM"].front() ).stripWhiteSpace().toFloat() );
 
                 if ( !file->xiphComment()->fieldListMap()[ "DISCNUMBER" ].isEmpty() )
-                    disc = TQString(TStringToQString( file->xiphComment()->fieldListMap()["DISCNUMBER"].front() )).stripWhiteSpace();
+                    disc = TStringToTQString( file->xiphComment()->fieldListMap()["DISCNUMBER"].front() ).stripWhiteSpace();
 
                 if ( !file->xiphComment()->fieldListMap()[ "COMPILATION" ].isEmpty() )
-                    compilation = TQString(TStringToQString( file->xiphComment()->fieldListMap()["COMPILATION"].front() )).stripWhiteSpace();
+                    compilation = TStringToTQString( file->xiphComment()->fieldListMap()["COMPILATION"].front() ).stripWhiteSpace();
             }
 
             if ( images && file->ID3v2Tag() ) {
@@ -601,7 +602,7 @@ MetaBundle::readTags( TagLib::AudioProperties::ReadStyle readStyle, EmbeddedImag
             TagLib::MP4::Tag *mp4tag = dynamic_cast<TagLib::MP4::Tag *>( file->tag() );
             if( mp4tag )
             {
-                setComposer( TQString(TStringToQString( mp4tag->composer() )) );
+                setComposer( TStringToTQString( mp4tag->composer() ) );
                 setBpm( TQString::number( mp4tag->bpm() ).toFloat() );
                 disc = TQString::number( mp4tag->disk() );
                 compilation = TQString::number( mp4tag->compilation() );
@@ -1282,7 +1283,7 @@ MetaBundle::genreList() //static
 
     TagLib::StringList genres = TagLib::ID3v1::genreList();
     for( TagLib::StringList::ConstIterator it = genres.begin(), end = genres.end(); it != end; ++it )
-        list += TStringToQString( (*it) );
+        list += TStringToTQString( (*it) );
 
     list.sort();
 
