@@ -141,7 +141,7 @@ PlayerWidget::PlayerWidget( TQWidget *parent, const char *name, bool enablePlayl
 
         KPushButton *switchView = new KPushButton( KGuiItem( "", "mini_dock" ), m_pFrameButtons );
         switchView->setSizePolicy( TQSizePolicy::Maximum, TQSizePolicy::Preferred ); // too big!
-        switchView->setFocusPolicy( TQ_NoFocus );
+        switchView->setFocusPolicy( TQWidget::NoFocus );
         connect( switchView, TQT_SIGNAL( clicked() ), TQT_SLOT( toggleView() ) );
 
 
@@ -557,7 +557,7 @@ bool PlayerWidget::event( TQEvent *e )
         return true;
 
     case 6/*TQEvent::KeyPress*/:
-        if (TQT_TQKEYEVENT(e)->key() == TQt::Key_D/* && (m_pAnalyzer->inherits(TQGLWIDGET_OBJECT_NAME_STRING)*/)
+        if (TQT_TQKEYEVENT(e)->key() == TQt::Key_D/* && (m_pAnalyzer->inherits("TQGLWidget")*/)
         {
             if( m_pAnalyzer->parent() )
             {
@@ -688,7 +688,7 @@ PlayerWidget::eventFilter( TQObject *o, TQEvent *e )
 {
     //NOTE we only monitor for parent() - which is the PlaylistWindow
 
-    if( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(m_pAnalyzer) )
+    if( o == m_pAnalyzer )
     {
         //delete analyzer, create same one back in Player Window
         if( e->type() == TQEvent::Close )
@@ -896,7 +896,7 @@ NavButton::NavButton( TQWidget *parent, const TQString &icon, TDEAction *action
     iconSet.setPixmap( pixmap, TQIconSet::Automatic, TQIconSet::Disabled, TQIconSet::Off );
     setIconSet( iconSet );
 
-    setFocusPolicy( TQ_NoFocus );
+    setFocusPolicy( TQWidget::NoFocus );
     setEnabled( action->isEnabled() );
 
     connect( action, TQT_SIGNAL( enabled( bool ) ),   TQT_SLOT( setEnabled( bool ) ) );
@@ -943,7 +943,7 @@ IconButton::IconButton( TQWidget *parent, const TQString &icon, const char *sign
     connect( this, TQT_SIGNAL(toggled( bool )), parent, signal );
 
     setToggleButton( true );
-    setFocusPolicy( TQ_NoFocus ); //we have no way to show focus on these widgets currently
+    setFocusPolicy( TQWidget::NoFocus ); //we have no way to show focus on these widgets currently
 }
 
 IconButton::IconButton( TQWidget *parent, const TQString &icon, TQObject* receiver, const char *slot )
@@ -954,7 +954,7 @@ IconButton::IconButton( TQWidget *parent, const TQString &icon, TQObject* receiv
     connect( this, TQT_SIGNAL(toggled( bool )), receiver, slot );
 
     setToggleButton( true );
-    setFocusPolicy( TQ_NoFocus ); //we have no way to show focus on these widgets currently
+    setFocusPolicy( TQWidget::NoFocus ); //we have no way to show focus on these widgets currently
 }
 
 void IconButton::drawButton( TQPainter *p )
