@@ -515,7 +515,7 @@ void UrlLoader::slotPlaylistInfo( const TQString &, const TQString &version, con
             "and this version can no longer read it.\n"
             "You will have to create a new one.\n"
             "Sorry :(" ) );
-        static_cast<MyXmlLoader*>( const_cast<TQT_BASE_OBJECT_NAME*>( sender() ) )->abort(); //HACK?
+        static_cast<MyXmlLoader*>( const_cast<TQObject*>( sender() ) )->abort(); //HACK?
         return;
     }
     else
