@@ -40,7 +40,7 @@ class TQTimer;
   */
 class PlaylistWindow : public TQWidget, public KXMLGUIClient
 {
-        Q_OBJECT
+        TQ_OBJECT
   
 
     public:
@@ -124,7 +124,7 @@ class PlaylistWindow : public TQWidget, public KXMLGUIClient
 
 class DynamicTitle : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         DynamicTitle( TQWidget* parent );
@@ -142,7 +142,7 @@ class DynamicTitle : public TQWidget
 
 class DynamicBar : public TQHBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         DynamicBar( TQWidget* parent );
