@@ -11,7 +11,7 @@
 
 class StdinReader : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
     
 
 public:
