@@ -149,7 +149,7 @@ Amarok::PrettySlider::PrettySlider( Qt::Orientation orientation, SliderMode mode
     if( m_mode == Pretty)
       {
         setWFlags( TQt::WNoAutoErase );
-        setFocusPolicy( TQ_NoFocus );
+        setFocusPolicy( TQWidget::NoFocus );
       }
 
     // We only have to connect this *once*, since our MetaBundle
@@ -357,7 +357,7 @@ Amarok::VolumeSlider::VolumeSlider( TQWidget *parent, uint max )
     , m_pixmapInset( TQPixmap( locate( "data","amarok/images/volumeslider-inset.png" ) ) )
 {
     setWFlags( getWFlags() | WNoAutoErase );
-    setFocusPolicy( TQ_NoFocus );
+    setFocusPolicy( TQWidget::NoFocus );
 
     if (TQPaintDevice::x11AppDepth() == 32) m_pixmapInset.convertFromImage(KImageEffect::convertToPremultipliedAlpha( m_pixmapInset.convertToImage() ));
 
