@@ -862,7 +862,7 @@ void CriteriaEditor::loadEditWidgets()
     /* Store lastCriteria. This information is used above to decide whether it's necessary to change the Widgets */
     m_lastCriteria = m_criteriaCombo->currentText();
 
-    TQObjectList* list = m_editBox->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList* list = m_editBox->queryList( "TQWidget" );
     for( TQObject *obj = list->first(); obj; obj = list->next()  )
         TQT_TQWIDGET(obj)->deleteLater();
 
