@@ -62,7 +62,7 @@ StarManager::reinitStars( int height, int margin )
     }
 
     int hval = m_height + m_margin * 2 - 4 + ( ( m_height % 2 ) ? 1 : 0 );
-    TQImage star = TQImage( locate( "data", "amarok/images/star.png" ) ).smoothScale( hval, hval, TQ_ScaleMin );
+    TQImage star = TQImage( locate( "data", "amarok/images/star.png" ) ).smoothScale( hval, hval, TQImage::ScaleMin );
     TQImage fullStar = TQImage( locate( "data", "amarok/images/star.png" ) );
     m_star = star.copy();
     m_fullStar = fullStar.copy();
@@ -71,7 +71,7 @@ StarManager::reinitStars( int height, int margin )
     m_greyedStar = star.copy();
     TDEIconEffect::toGray( m_greyedStar, 1.0 );
     m_greyedStarPix.convertFromImage( m_greyedStar );
-    TQImage half = TQImage( locate( "data", "amarok/images/smallstar.png" ) ).smoothScale( hval, hval, TQ_ScaleMin );
+    TQImage half = TQImage( locate( "data", "amarok/images/smallstar.png" ) ).smoothScale( hval, hval, TQImage::ScaleMin );
     TQImage fullHalf = TQImage( locate( "data", "amarok/images/smallstar.png" ) );
     m_halfStar = half.copy();
     m_fullHalfStar = fullHalf.copy();
