@@ -20,16 +20,16 @@
 #include "statistics.h"
 #include "tagdialog.h"         //showContextMenu()
 
-#include <kapplication.h>
-#include <kdeversion.h>        //KDE_VERSION ifndefs.  Remove this once we reach a kde 4 dep
+#include <tdeapplication.h>
+#include <tdeversion.h>        //TDE_VERSION ifndefs.  Remove this once we reach a kde 4 dep
 #include <kiconloader.h>
-#include <klocale.h>
-#include <kmultipledrag.h>     //startDrag()
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdemultipledrag.h>     //startDrag()
+#include <tdepopupmenu.h>
 #include <kstringhandler.h>    //paintCell
-#include <ktoolbarbutton.h>    //ctor
+#include <tdetoolbarbutton.h>    //ctor
 #include <kurldrag.h>          //startDrag()
-#include <kwin.h>
+#include <twin.h>
 
 #include <tqcolor.h>
 #include <tqdatetime.h>
@@ -69,12 +69,12 @@ Statistics::Statistics( TQWidget *parent, const char *name )
     box->setSpacing( 5 );
 
     { //<Search LineEdit>
-        KToolBar *bar = new Browser::ToolBar( box );
+        TDEToolBar *bar = new Browser::ToolBar( box );
         bar->setIconSize( 22, false ); //looks more sensible
         bar->setFlat( true ); //removes the ugly frame
         bar->setMovingEnabled( false ); //removes the ugly frame
 
-        TQWidget *button = new KToolBarButton( "locationbar_erase", 1, bar );
+        TQWidget *button = new TDEToolBarButton( "locationbar_erase", 1, bar );
         m_lineEdit = new ClickLineEdit( i18n( "Enter search terms here" ), bar );
 
         bar->setStretchableWidget( m_lineEdit );
@@ -120,7 +120,7 @@ Statistics::slotSetFilter() //SLOT
 //////////////////////////////////////////////////////////////////////////////////////////
 
 StatisticsList::StatisticsList( TQWidget *parent, const char *name )
-    : KListView( parent, name )
+    : TDEListView( parent, name )
     , m_currentItem( 0 )
     , m_expanded( false )
 {
@@ -314,7 +314,7 @@ void
 StatisticsList::expandInformation( StatisticsItem *item, bool refresh )
 {
     m_expanded = true;
-    KLocale *locale = new KLocale( "locale" );
+    TDELocale *locale = new TDELocale( "locale" );
 
     QueryBuilder qb;
 
@@ -600,7 +600,7 @@ StatisticsList::clearHover() //SLOT
 void
 StatisticsList::viewportPaintEvent( TQPaintEvent *e )
 {
-    if( e ) KListView::viewportPaintEvent( e );
+    if( e ) TDEListView::viewportPaintEvent( e );
 
     if( CollectionDB::instance()->isEmpty() && e )
     {
@@ -638,7 +638,7 @@ StatisticsList::showContextMenu( TQListViewItem *item, const TQPoint &p, int )
 
     bool hasSQL = !( item->itemType() == StatisticsDetailedItem::TRACK ); //track is url
 
-    KPopupMenu menu( this );
+    TDEPopupMenu menu( this );
     enum Actions { APPEND, QUEUE, INFO };
 
     menu.insertItem( SmallIconSet( Amarok::icon( "add_playlist" ) ), i18n( "&Append to Playlist" ), APPEND );
@@ -681,8 +681,8 @@ StatisticsList::showContextMenu( TQListViewItem *item, const TQPoint &p, int )
 /// CLASS StatisticsItem
 //////////////////////////////////////////////////////////////////////////////////////////
 
-StatisticsItem::StatisticsItem( TQString text, StatisticsList *parent, KListViewItem *after, const char *name )
-    : KListViewItem( static_cast<KListView*>(parent), after, name )
+StatisticsItem::StatisticsItem( TQString text, StatisticsList *parent, TDEListViewItem *after, const char *name )
+    : TDEListViewItem( static_cast<TDEListView*>(parent), after, name )
     , m_animTimer( new TQTimer( this ) )
     , m_animCount( 0 )
     , m_isActive( false )
@@ -700,8 +700,8 @@ StatisticsItem::StatisticsItem( TQString text, StatisticsList *parent, KListView
 void
 StatisticsItem::setIcon( const TQString &icon )
 {
-    TQString path = kapp->iconLoader()->iconPath( icon, -KIcon::SizeHuge );
-    path.replace( "32x32", "48x48" ); //HACK: KIconLoader only returns 32x32 max. Why?
+    TQString path = kapp->iconLoader()->iconPath( icon, -TDEIcon::SizeHuge );
+    path.replace( "32x32", "48x48" ); //HACK: TDEIconLoader only returns 32x32 max. Why?
 
 //     debug() << "ICONPATH: " << path << endl;
 
@@ -764,7 +764,7 @@ StatisticsItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int
     }
     else //alternate colours
     {
-    #if KDE_VERSION < KDE_MAKE_VERSION(3,3,91)
+    #if TDE_VERSION < TDE_MAKE_VERSION(3,3,91)
         fillColor = isSelected() ? cg.highlight() : backgroundColor();
     #else
         fillColor = isSelected() ? cg.highlight() : backgroundColor(0);
@@ -779,7 +779,7 @@ StatisticsItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int
 
     if( buffer.isNull() )
     {
-        KListViewItem::paintCell( p, cg, column, width, align );
+        TDEListViewItem::paintCell( p, cg, column, width, align );
         return;
     }
 
@@ -787,7 +787,7 @@ StatisticsItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int
 
     TQPainter pBuf( &buffer, true );
 
-    KListView *lv = static_cast<KListView *>( listView() );
+    TDEListView *lv = static_cast<TDEListView *>( listView() );
 
     TQFont font( p->font() );
     font.setBold( true );
@@ -859,7 +859,7 @@ StatisticsItem::blendColors( const TQColor& color1, const TQColor& color2, int p
 
 StatisticsDetailedItem::StatisticsDetailedItem( const TQString &text, const TQString &subtext, StatisticsItem *parent,
                                                 StatisticsDetailedItem *after, const char *name )
-    : KListViewItem( parent, after, name )
+    : TDEListViewItem( parent, after, name )
     , m_type( NONE )
     , m_subText( subtext )
 {
@@ -881,19 +881,19 @@ StatisticsDetailedItem::paintCell( TQPainter *p, const TQColorGroup &cg, int col
 
     if( buffer.isNull() )
     {
-        KListViewItem::paintCell( p, cg, column, width, align );
+        TDEListViewItem::paintCell( p, cg, column, width, align );
         return;
     }
 
     TQPainter pBuf( &buffer, true );
     // use alternate background
-#if KDE_VERSION < KDE_MAKE_VERSION(3,3,91)
+#if TDE_VERSION < TDE_MAKE_VERSION(3,3,91)
     pBuf.fillRect( buffer.rect(), isSelected() ? cg.highlight() : backgroundColor() );
 #else
     pBuf.fillRect( buffer.rect(), isSelected() ? cg.highlight() : backgroundColor(0) );
 #endif
 
-    KListView *lv = static_cast<KListView *>( listView() );
+    TDEListView *lv = static_cast<TDEListView *>( listView() );
 
     TQFont font( p->font() );
     TQFontMetrics fm( p->fontMetrics() );
