@@ -74,7 +74,7 @@ namespace SingleShotPool
     {
         TQTimer *timer = static_cast<TQTimer*>( parent->child( slot ) );
 
-        return timer && timer->isA( TQTIMER_OBJECT_NAME_STRING ) && timer->isActive();
+        return timer && timer->isA( "TQTimer" ) && timer->isActive();
     }
 }
 
@@ -148,7 +148,7 @@ StatusBar::polish()
     TQWidget::polish();
 
     int h = 0;
-    TQObjectList *list = queryList( TQWIDGET_OBJECT_NAME_STRING, 0, false, false );
+    TQObjectList *list = queryList( "TQWidget", 0, false, false );
 
     for( TQObject * o = list->first(); o; o = list->next() ) {
         int _h = TQT_TQWIDGET( o ) ->minimumSizeHint().height();
@@ -157,7 +157,7 @@ StatusBar::polish()
 
 //         debug() << o->className() << ", " << o->name() << ": " << _h << ": " << TQT_TQWIDGET(o)->minimumHeight() << endl;
 
-        if ( o->inherits( TQLABEL_OBJECT_NAME_STRING ) )
+        if ( o->inherits( "TQLabel" ) )
             static_cast<TQLabel*>(TQT_TQWIDGET(o))->setIndent( 4 );
     }
 
@@ -172,7 +172,7 @@ StatusBar::polish()
 void
 StatusBar::paintEvent( TQPaintEvent* )
 {
-    TQObjectList *list = queryList( TQWIDGET_OBJECT_NAME_STRING, 0, false, false );
+    TQObjectList *list = queryList( "TQWidget", 0, false, false );
     TQPainter p( this );
 
     for( TQObject * o = list->first(); o; o = list->next() ) {
@@ -417,7 +417,7 @@ StatusBar::newProgressOperation( TDEIO::Job *job )
 void
 StatusBar::endProgressOperation()
 {
-    TQObject *owner = TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>( sender() )); //HACK deconsting it
+    TQObject *owner = TQT_TQOBJECT(const_cast<TQObject*>( sender() )); //HACK deconsting it
     TDEIO::Job *job = dynamic_cast<TDEIO::Job*>( owner );
 
     //FIXME doesn't seem to work for TDEIO::DeleteJob, it has it's own error handler and returns no error too
@@ -509,7 +509,7 @@ StatusBar::hideMainProgressBar()
 void
 StatusBar::setProgress( int steps )
 {
-    setProgress( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender())), steps );
+    setProgress( sender(), steps );
 }
 
 void
@@ -551,7 +551,7 @@ StatusBar::setProgressStatus( const TQObject *owner, const TQString &text )
 
 void StatusBar::incrementProgress()
 {
-    incrementProgress( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()) ));
+    incrementProgress( sender() );
 }
 
 void
