@@ -37,7 +37,7 @@
 
 class ToggleLabel : public TQLabel
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     TDEToggleAction const*const m_action;
