@@ -25,7 +25,7 @@
 
 class MetaBundle::XmlLoader::ThreadedLoader: public TQObject, public TQThread
 {
-    Q_OBJECT
+    TQ_OBJECT
   
     TQObject *m_target;
     TQXmlInputSource *m_source;
@@ -57,7 +57,7 @@ class MetaBundle::XmlLoader::ThreadedLoader: public TQObject, public TQThread
 
 class MetaBundle::XmlLoader::SimpleLoader: public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
